pub enum Mode {
Real,
Effective,
Existing,
Original,
}Expand description
A SetUID mode.
Variants
Real
Transition to the Real user, setting both Real and Effective
to USER.real, while saving Effective to Saved.
Effective
Transition to the Effective user, setting both Real and Effective
to USER.effective, while saving Real to Saved.
Existing
The current operating mode. This is functionally a no-op except for in drop, where it drops whatever the current mode happens to be.
Original
Revert to the program’s original operating mode. For set, this mode is functionally identical to using revert(). For drop, it acts as user::revert().