pub fn current() -> Result<Mode, Errno>Expand description
Get the current user mode Note that this is not thread-safe, and your program can suffer from TOC-TOU problems if you assume this value will remain the same when you actually need to perform a privileged operation in a multi-threaded environment.